<?php
/**
 * Gets all of the property values for one or more assets
 *
 * This function returns the values of all properties for each of the given asset(s).
 *
 * It is used when you either want ALL asset information for display, or when you
 *    are not clear on the structure of ARDI data and would like to process it without
 *    dealing with metadata queries. 
 *
 * @author Steven Harding
 */	

$groupid = 0;
if (!isset($_REQUEST['groupid']))
 {
	header("HTTP/1.1 404 Missing Parameters");
	exit;
 }
 
$groupid = $_REQUEST['groupid'];
 
$format = "xml";
if (isset($_REQUEST['format']))
{
	$format = $_REQUEST['format'];
}

$contacttag = 0;

//Locate the 'contact' tag....
$query = $db->query("SELECT id FROM assets WHERE name='Contact' AND type=1");
if($row = $query->fetch(PDO::FETCH_ASSOC)) 
{
	$contacttag = $row['id'];
}


ob_start();

echo '<results>';

$ass = new Asset($groupid);
$props = $ass->GetProperties();
$ass->GetValues($props);

$methodlist = "";

foreach($props as $p)
{
	if ($p->type == "_NOTIFIERMETHODS")
	{
		//Bingo - we now know which methods to use...
		$methodlist = $p->value['methodlist'];
	}
}
$propsneeded = array();
$activemethods = explode(',',$methodlist);
foreach($activemethods as $meth)
{
	$fldr = $installfolder.'/addons/notifier/methods/'.$meth.'.inc';
	if (file_exists($fldr))
	{
		include($fldr);
		
		//Check to see what type of field is required...
		if (isset($method['requires']))
		{
			foreach($method['requires'] as $req)
			{
				$propsneeded[] = $req;
			}
		}
	}
}

$groups = array();
$query = $db->query('SELECT id FROM assets JOIN assetrelclosures ON (childasset=assets.id) WHERE parentasset='.$groupid.' AND type=0 ORDER BY name');
while($row = $query->fetch(PDO::FETCH_ASSOC)) 
{
	$contacts[] = $row['id'];
}

foreach($contacts as $uid)
{
	$ass = new Asset($uid);
	$props = $ass->GetProperties();
	$ass->GetValues($props);
	$ass->Fetch($props);
	
	//Check availability..
	
	$unavail = false;
	foreach($props as $p)
	{
		if ($p->type == "AVAILABLE")
		{
			if ($p->value['available'] == 0)
			{
				$unavail = true;
			}
		}
	}
	if ($unavail == true)
	{
		echo '<unavailable id="'.$ass->id.'" name="'.$ass->name.'"/>';
		continue;
	}

	echo '<contact id="'.$ass->id.'" name="'.$ass->name.'">';
	
	foreach($props as $p)
	{
		if (in_array($p->type,$propsneeded))
		{
			echo '   <value type="'.$p->type.'"';
			foreach($p->value as $k => $v)
			{
				if ($p->origin != $uid) continue;
				$bound = htmlspecialchars(str_replace(" ","_",$k));
				echo ' '.$bound.'="'.$v.'"';
			}
			echo '/>';
		}
	}
	
	echo '</contact>';
}

$methods = array();
$query = $db->query('SELECT code, parameters FROM notifier_methods');
while($row = $query->fetch(PDO::FETCH_ASSOC)) 
{
	$methods[$row['code']] = $row['parameters'];
}

foreach($methods as $k => $v)
{
	if (!in_array($k,$activemethods)) continue;
	echo '<method code="'.$k.'">'.$v.'</method>';
}
		
echo '</results>';

if ($format != "xml")
{
	$content = ob_get_clean();
	if ($format == 'json')
	{
		$xml = simplexml_load_string($content);
		$json = json_encode($xml);
		echo $json;
		exit;
	}
}

?>